docker-py gamechanger fork
=========
The reason we are cutting this fork is this [issue](https://github.com/docker/docker-py/issues).
We hope this to be a temporary measure till docker-py is updated for docker 1.7.

Link to the real [docker-py repo](https://github.com/docker/docker-py)
